/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.pango;

import org.gnu.glib.Handle;

/**
 * The PangoAttrInt object is used to represent attributes with a integer value
 */
public class AttrInt extends Attribute {

    /**
     * Returns the value of the object.
     */
    public int getValue() {
        return getValue(getHandle());
    }

    native static final protected int getValue(Handle obj);
}
